@@ -1,13 +1,14 @@
-package HTTP::Server::Simple;
 use strict;
 use warnings;
+
+package HTTP::Server::Simple;
 use FileHandle;
 use Socket;
 use Carp;
 use URI::Escape;
 
 use vars qw($VERSION $bad_request_doc);
-$VERSION = '0.28';
+$VERSION = '0.29';
 
 
 =head1 NAME
@@ -73,6 +74,60 @@ could kill the server
 
 =back
 
+=head1 EXAMPLE
+ 
+ #!/usr/bin/perl
+ {
+ package MyWebServer;
+ 
+ use HTTP::Server::Simple::CGI;
+ use base qw(HTTP::Server::Simple::CGI);
+ 
+ my %dispatch = (
+     '/hello' => \&resp_hello,
+     # ...
+ );
+ 
+ sub handle_request {
+     my $self = shift;
+     my $cgi  = shift;
+   
+     my $path = $cgi->path_info();
+     my $handler = $dispatch{$path};
+ 
+     if (ref($handler) eq "CODE") {
+         print "HTTP/1.0 200 OK\r\n";
+         $handler->($cgi);
+         
+     } else {
+         print "HTTP/1.0 404 Not found\r\n";
+         print $cgi->header,
+               $cgi->start_html('Not found'),
+               $cgi->h1('Not found'),
+               $cgi->end_html;
+     }
+ }
+ 
+ sub resp_hello {
+     my $cgi  = shift;   # CGI.pm object
+     return if !ref $cgi;
+     
+     my $who = $cgi->param('name');
+     
+     print $cgi->header,
+           $cgi->start_html("Hello"),
+           $cgi->h1("Hello $who!"),
+           $cgi->end_html;
+ }
+ 
+ } 
+ 
+ # start the server on port 8080
+ my $pid = MyWebServer->new(8080)->background();
+ print "Use 'kill $pid' to stop server.\n";
+
+=head1 METHODS 
+
 =head2 HTTP::Server::Simple->new($port)
 
 API call to start a new server.  Does not actually start listening
@@ -645,7 +700,7 @@ sub valid_http_method {
 
 =head1 AUTHOR
 
-Copyright (c) 2004-2006 Jesse Vincent, <jesse@bestpractical.com>.
+Copyright (c) 2004-2008 Jesse Vincent, <jesse@bestpractical.com>.
 All rights reserved.
 
 Marcus Ramberg <drave@thefeed.no> contributed tests, cleanup, etc
@@ -653,6 +708,8 @@ Marcus Ramberg <drave@thefeed.no> contributed tests, cleanup, etc
 Sam Vilain, <samv@cpan.org> contributed the CGI.pm split-out and
 header/setup API.
 
+Example section by almut on perlmonks, suggested by Mark Fuller.
+
 =head1 BUGS
 
 There certainly are some. Please report them via rt.cpan.org
